@@ -1,5 +1,7 @@
 #include "gba.h"
 
+extern u32 seconds;
+
 void (*IntrTable[14])(void);
 
 void interrupt_dummy(void) {
@@ -12,6 +14,11 @@ void interrupt_key(void) {
   );
 }
 
+void interrupt_timer2(void)
+{
+	seconds++;
+}
+
 void interrupt_init(void) {
   int i;
 
@@ -20,5 +27,6 @@ void interrupt_init(void) {
 
   // Set selected interrupts to do something fun/useful.
   IntrTable[12] = (void (*)(void))interrupt_key;
+	IntrTable[5] = (void (*)(void))interrupt_timer2;
 	//IntrTable[4] =  (void (*)(void))interrupt_sound;
 }
