@@ -56,7 +56,7 @@ int pythag(float dx, float dy)
 #define MOVE_TR		1 << 5
 
 #include "walltextures.raw.c"
-#include "walltextures.pal.c"
+#include "master.pal.c"
 
 //#define TRACE(x...) printf(x)
 //#define TRACE(x...) sprintf(foo, x); print(foo)
@@ -150,7 +150,8 @@ void raycast()
 {
 	int i;
 	char foo[100];
-
+	s32 dbuf[SCREEN_WIDTH];
+	
 	/* scan across the screen */
 	for(i=0; i < SCREEN_WIDTH; i++)
 	{
@@ -315,12 +316,14 @@ void raycast()
 		TRACE("adjusted distance: %d\n", distance);
 
 		slice_height = FIXED(64 * PROJECTION_DISTANCE)  / distance;
-		
+		dbuf[i] = FIXED_TO_INT(distance);
+
 		/* draw here! */
 		asm_rasterise_line(i, slice_height, walltextures_Bitmap + 
 			(map[((wall_hit_y/64) * MAP_SIZE_X) + (wall_hit_x/64)] - 1)*64*64,
 			texture_offset);
 	}
+	objs_draw(px, py, pa, dbuf);
 }
 
 void player_move(s32 angle)
@@ -376,7 +379,7 @@ int AgbMain()
 	//trigtest();
 	SetMode(MODE_4 | BG2_ENABLE);
 	for(i=0; i < 256; i++)
-		BGPaletteMem[i] = walltextures_Palette[i];
+		BGPaletteMem[i] = master_Palette[i];
 	
 	gba_initbank();
 
@@ -409,7 +412,6 @@ int AgbMain()
 		if(pa > 360) pa -= 360;
 
 		//sprintf(foo, "px: %4d py: %4d pa: %3d\n", px, py, pa); print(foo);
-		//objs_draw(px, py, pa);
 
 		if(movement & MOVE_UP)
 		{
