@@ -23,6 +23,7 @@ void print(char *s);
 s32 gba_sin(s32 angle);
 s32 gba_cos(s32 angle);
 s32 gba_tan(s32 angle);
+s32 gba_atan(s32 y, s32 x);
 
-void objs_draw(s32 px, s32 py, s32 angle);
+void objs_draw(s32 px, s32 py, s32 angle, s32* dist_buf);
 int pythag(float x, float y);
