@@ -75,3 +75,43 @@ s32 gba_tan(s32 angle)
 	return(res >> 8);
 }
 
+s32 gba_atan(s32 y, s32 x)
+{
+	s32 tanval;
+	s32 angle;
+
+	if(x == 0)
+	{
+		angle = 90 * 4;
+	} else if(y == 0) {
+		angle = 0;
+	} else {
+		tanval = abs((y << 16) / x);
+		angle = 0;
+
+		while(angle < (90*4)+1)
+		{
+			if(tan_table[angle] > tanval) break;
+			angle++;
+		}
+	}
+	angle = angle * 64;
+	
+	/* move angle to appropriate quadrant */
+	if(x < 0)
+	{
+		if(y > 0)
+		{
+			angle = FIXED(180) - angle;
+		} else {
+			angle = FIXED(180) + angle;
+		}
+	} else {
+		if(y < 0)
+		{
+			angle = FIXED(360) - angle;
+		}
+	}
+
+	return angle;
+}
